@@ -1,8 +1,8 @@
-condIsomap <- function (d, V, u.dim, epsilon = NULL, k, W = NULL,
+condIsomap <- function (d, V, u.dim, epsilon = NULL, k, W,
                         method = c('matrix', 'vector'),
                         it.max = 1000, gamma = 1e-05,
-                        init = c('none', 'user'),
-                        U.start = NULL, B.start = NULL, b.start = NULL, ...)
+                        init = c('none', 'eigen', 'user'),
+                        U.start, B.start, ...)
 {
   if (is.null(epsilon)) {
     d <- vegan::isomapdist(d, k=k,...)
@@ -12,6 +12,5 @@ condIsomap <- function (d, V, u.dim, epsilon = NULL, k, W = NULL,
 
   condMDS(d = d, V = V, u.dim = u.dim, W = W,
           method = method, it.max = it.max, gamma = gamma,
-          init = init, U.start = U.start,
-          B.start = B.start, b.start = b.start)
+          init = init, U.start = U.start, B.start = B.start)
 }
